#
# spec file for package filezilla
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           filezilla
Version:        3.31.0
Release:        bp154.1.66
Summary:        A GUI FTP and SFTP Client
License:        GPL-2.0+
Group:          Productivity/Networking/Ftp/Clients
Url:            https://filezilla-project.org/
Source0:        http://download.filezilla-project.org/client/FileZilla_%{version}_src.tar.bz2
# PATCH-FIX-OPENSUSE filezilla-3.22.2-buildinfo-no-date.patch
Patch1:         filezilla-3.22.2-buildinfo-no-date.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  libtool
# needs long long support in pugixml
BuildRequires:  pugixml-devel >= 1.7
BuildRequires:  update-desktop-files
BuildRequires:  wxWidgets-3_0-devel >= 3.0.3
BuildRequires:  xdg-utils
BuildRequires:  pkgconfig(cppunit)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(gnutls) >= 3.4.15
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(libfilezilla) >= 0.12.1
BuildRequires:  pkgconfig(libidn)
BuildRequires:  pkgconfig(nettle) >= 3.1
# filezilla-team use BuildRequires:  pkgconfig(sqlite3) >= 3.11.1
BuildRequires:  pkgconfig(sqlite3) >= 3.7.8
Recommends:     %{name}-lang
%if 0%{?suse_version} <= 1500
# FileZilla requires C++14 support.
BuildRequires:  gcc7-c++
%else
BuildRequires:  gcc-c++
%endif
# See boo#966384 filezilla fails to start
Requires:       libpugixml1 >= 1.7

%description
FileZilla is a modern and powerful FTP client.
FileZilla development focuses on high usability while also
supporting as many useful features as possible.

Some of the main features are:
 * Continuing interrupted up-/downloads.
 * Managing different FTP sites.
 * Modifiable Commands.
 * Keep-Alive-System.
 * Timeout detection.
 * Firewall support.
 * SOCKS4/5 and HTTP 1.1 proxy support.
 * SSL support (secure connections).
 * SFTP support.
 * Upload/Download queue.
 * Drag&Drop support.

%lang_package

%prep
%setup -q
%patch1 -p1

# Fix invalid translation locales:
cd locales
for LOC in\
    bg_BG\
    ca_ES@valencia\
    cs_CZ\
    fa_IR\
    fi_FI\
    gl_ES\
    he_IL\
    hu_HU\
    id_ID\
    ja_JP\
    km_KH\
    ko_KR\
    lo_LA\
    lt_LT\
    lv_LV\
    mk_MK\
    nb_NO\
    nn_NO\
    pl_PL\
    pt_BR\
    pt_PT\
    ro_RO\
    sk_SK\
    sl_SI\
    th_TH\
    uk_UA\
    vi_VN\
    zh_CN\
    zh_TW;
do
    mv -iv $LOC.po ${LOC/_??}.po
done

%build
%if 0%{?suse_version} <= 1500
export CC="gcc-7"
export CXX="g++-7"
# Default ABI through G++4.9, thus the one wxWidgets uses.
export CXXFLAGS="%{optflags} -fabi-version=2 -fabi-compat-version=2"
%endif
autoreconf -fi
%configure \
  --disable-static            \
  --disable-manualupdatecheck \
  --disable-autoupdatecheck   \
  --with-dbus
make %{?_smp_mflags}

%install
%make_install
%suse_update_desktop_file %{name}
%fdupes %{buildroot}%{_datadir}/
%find_lang %{name}

%check
make check %{?_smp_mflags}

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%defattr(-,root,root)
%doc README NEWS COPYING
%{_bindir}/%{name}
%{_bindir}/fzsftp
%{_bindir}/fzputtygen
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.*
%{_datadir}/icons/hicolor/480x480
%{_datadir}/icons/hicolor/480x480/apps
%{_datadir}/pixmaps/%{name}.png
%dir %{_datadir}/appdata/
%{_datadir}/appdata/%{name}.appdata.xml
%{_mandir}/man1/filezilla.1%{?ext_man}
%{_mandir}/man1/fzputtygen.1%{?ext_man}
%{_mandir}/man1/fzsftp.1%{?ext_man}
%{_mandir}/man5/fzdefaults.xml.5%{?ext_man}

%files lang -f %{name}.lang
%defattr(-,root,root)

%changelog
* Mon Mar  5 2018 ecsos@opensuse.org
- Update require libfilezilla to 0.12.1 as described in configure
* Sat Feb 24 2018 ecsos@opensuse.org
- update to 0.31.0
  * New features:
  - Allow trusting all subject alternative names (SAN) in a
    certificate if the current hostname matches the certificate
  * Bugfixes and minor changes:
  - OS X: Fix file lists becoming inresponsive when a file rename
    edit box is discarded by clicking to the right of the last
    column in the file list
  - Fix rare crash during directory removal
  - Fix rare crash in the transfer queue
* Thu Jan 25 2018 ecsos@opensuse.org
- update to 0.30.0
  * Bugfixes and minor changes:
  - Add additional logging if autoupdate mechanism fails
- update to 3.30.0-rc1
  * New features:
  - In the search dialog local files can now be deleted or opened
  - The root node in the remote directory tree is now expanded
    by default
  * Bugfixes and minor changes:
  - Fix uploading from search dialog
  - Fix formatting of filename in rename dialog
  - MSW: Fix installer crash if an update installation is started
    with the updated version having been installed
* Sun Nov 12 2017 ecsos@opensuse.org
- update to 0.29.0
  * Bugfixes and minor changes:
  - Fix activity indicators not working after the update check
    has been run
- update to 0.29.0-rc1
  * New features:
  - Added new quick search filter to file lists,
    accessed through Ctrl+F
  - FTP over TLS: Mismatched hostnames are now highlighted in red
    in the certificate verification dialog
  - Filters using regular expressions can now be case-insensitive
  * Bugfixes and minor changes:
  - Explicitly wait for the settings to be written to disk before
    removing the backup file to prevent loss of data in case of
    system crashes
* Mon Oct  2 2017 ecsos@opensuse.org
- update to 3.28.0
  * New features:
  - *nix: Official Linux binaries are now built for Debian 9
    (Stretch)
  * Bugfixes and minor changes:
  - Do not disable password saving settings if fzdefaults.xml
    contains a kiosk mode setting of 0.
- update to 3.28.0-rc1
  * New features:
  - Add "Close once" as queue completion action
  * Bugfixes and minor changes:
  - Fixed crash if FileZilla is forced to close, e.g. when the
    system is shutting down, while there are open dialogs
  - If the transfer queue asks for a password and the password
    dialog is canceled the queue processing is now stopped
  - OS X, *nix: Improve detection of invalid character encodings
    in local filenames
  - Fix potential crash expanding directory tree items while
    changing selections
* Sun Aug 20 2017 ecsos@opensuse.org
- update to 3.27.1
  * Fixed vulnerabilities:
  - Change client identification string if connecting with SFTP
    due to OpenSSH disregarding the supported ciphers announced
    by the client, resulting in less secure algorithms being
    chosen by OpenSSH.
  * Bugfixes and minor changes:
  - MSW: Improve handling of NTFS reparse points
  - MSW: If running the installer with /S, previous versions
    where not uninstalled prior to the new version being
    installed
  - MSW: The installer can be run with /quiet for a semi-silent
    installation
  - OS X, *nix: Potential fix for a rare crash if changing local
    directories while the local directory list is being updated
    and vice versa.
- remove patch putty-no_DATE_and_TIME_.patch because it is now in
  upstream
* Thu Aug 10 2017 ecsos@opensuse.org
- add COPYING file to %%doc
* Sat Aug  5 2017 ecsos@opensuse.org
- update to 3.27.0.1
  * Bugfixes and minor changes:
  - MSW: Add misssing file to .zip binary package
  - MSW: Fix toolchain issues breaking the shell extension
- update to 3.27.0
  * Bugfixes and minor changes:
  - SFTP components have been updated and are now based on
    PuTTY 0.70
- update to 3.27.0-rc1
  * New features:
  - Support for the Storj decentralized cloud storage provider
  * Bugfixes and minor changes:
  - MSW: Fix display of file type of directories if the directory
    name contains a dot
  - Fix assertion if entering an invalid protocol prefix into the
    host field on the quickconnect bar or in the site manager
  - Improve error message if TLS certificate verification fails
    due to a missing stapled OCSP resonse
  - Building and running FileZilla now depends on
    libfilezilla >= 0.10.0 (https://lib.filezilla-project.org/)
* Thu Jun 15 2017 ecsos@opensuse.org
- update to 3.26.2
  * Bugfixes and minor changes:
  - Fixed crash if using master passwords and decrypting very
    long passwords
* Sun Jun  4 2017 ecsos@opensuse.org
- update to 3.26.1
  * Bugfixes and minor changes:
  - Fixed crash if changing password settings and the
    Site Manager contains subdirectories
  - *nix: Fixed saving of sites having more than one
    site-specific bookmark
- update to 3.26.0
  * Bugfixes and minor changes:
  - When changing or removing the master password, update
    protected credentials of server items in the transfer queue
  - Fix display of remember checkbox when showing the password
    entry dialog for sites that have no username set and are
    using the "Ask" logon type
  - Some icons were missing in the Windows .zip binary archive
- update to 3.26.0-rc1
  * New features:
  - Passwords can now be stored encrypted, protected with
    a master password
  - Building and running FileZilla now depends on
    libfilezilla >= 0.9.2 (https://lib.filezilla-project.org/).
  - Building and running FileZilla now depends on
    wxWidgets >= 3.0.3
* Tue May  2 2017 ecsos@opensuse.org
- update to 3.25.2
  * Bugfixes and minor changes:
  - SFTP components have been updated and are now based on
    PuTTY 0.69
  - Fixed potential stall during the final listing operation when
    finishing a queue which contained uploads
- update to 3.25.2-rc1
  * Bugfixes and minor changes:
  - Fix crash if filters.xml has become corrupted
  - Fix FTP proxy support
  - Fix sending of FTP keep-alive commands
  - MSW: Windows Vista is no longer supported
  - MSW: File and directory icons now also appear on systems that
    have no Windows directory
- update to 3.25.1
  * Bugfixes and minor changes:
  - OS X: Fixed a crash if connecting to old servers not
    supporting UTF-8
  - Fixed timeout detection
* Wed Mar 15 2017 ecsos@opensuse.org
- update to 3.25.0
  * New features:
  - OS X: The minimum required OS X version is now 10.9
  * Bugfixes and minor changes:
  - OS X: Disable App Nap during transfers and other operations
  - OS X: Downloaded updates are now stored in the Downloads
    directory
  - OS X: Fix initial toolbar state on startup if it was hidden
    when FileZilla was last closed
  - Fix reconnect delay logic which broke in 3.25.0-beta1
  - Fix piecewise creation of remote paths using FTP which broke
    in 3.25.0-beta1
- update to 3.25.0-rc1
  * Bugfixes and minor changes:
  - Fix encryption selection for FTP in the Site Manager which
    broke in 3.25.0-beta1
  - Small changes to error message texts
- update to 3.25.0-beta1
  * New features:
  - Major refactoring of the FileZilla internals.
  * Bugfixes and minor changes:
  - Scale width of fields in the status line control on high-DPI
    displays
  - Fix duplicate mnemonic in "Files currently being edited"
    dialog.
- Drop patch filezilla-3.24.1-config_parse_error.patch because now
  in upstream
* Thu Feb 23 2017 ecsos@opensuse.org
- update to 3.24.1
  * Bugfixes and minor changes:
  - Fixed rendering icons in the remote directory tree when DPI
    scaling is enabled on Windows Vista and some Windows 7
    machines
  - SFTP components have been updated and are now based on
    PuTTY 0.68
  - Updated builtin pugixml to version 1.8
- Add patch filezilla-3.24.1-config_parse_error.patch to prevent
  build error.
* Sun Jan 15 2017 ecsos@opensuse.org
- update to 3.24.0
  * Bugfixes and minor changes:
  - Fixed a possible crash if sending FTP commands fails during
    a directory listing operation
  - *nix: Fixed a scrolling issue in the message log if wxWidgets
    is built against GTK3
- update to 3.24.0-rc1
  * New features:
  - The context menu for remote file search results now has
    a "Copy URL(s) to clipboard" item
  - Alt+number can now be used to switch between tabs in addition
    to Ctrl+number
  - SFTP hostkey fingerprints are now also shown as base64
    encoded SHA256 hashes to match the new format displayed by
    OpenSSH
  * Bugfixes and minor changes:
  - Errors at the end of SFTP transfers now correctly result in
    transfer failures instead
  - Cancelling synchronized browsing questions no longer prevents
    further directory changes
  - Fix display issues for the filter conditions dialog
  - Fix deleting multiple extensions on the filetype page in the
    settings
  - OS X: Do not open dialogs while already processing an event,
    e.g. while a context menu is open
* Tue Dec  6 2016 ecsos@opensuse.org
- update to 3.23.0.2
  * Bugfixes and minor changes:
  - Key file paths entered in the Site Manager are now saved to
    corresponding server entries in the transfer queue
  - MSW: Work around a bug in wxWidgets causing bad icons in the
    remote directory tree due to wxImageList::GetBitmap
    errorneously stripping the alpha channel from images
  - Allow relative paths and environment variables in the
    "Cache directory" setting.
- update to 3.23.0.1
  * Bugfixes and minor changes:
  - Work around a bug in wxWidgets that has been causing a
    virtually infinite loop when deleting toolbar buttons
- update to 3.23.0
  * Bugfixes and minor changes:
  - Speed up icon scaling and cache scaled icons for faster
    subsequent loading. The cache directory can be changed
    through fzdefaults.xml using the "Cache directory" setting
  - OS X: Fixed icon display on high-DPI displays in a few more
    dialogs
  - Loading a corrupted layout.xml or search.xml no longer shows
    an error message, these files are now silently overwritten
  - MSW: Fixed a regression where UNC paths where not handled
    correctly as config location in fzdefaults.xml
- update to 3.23.0-rc1
  * New features:
  - New high-resolution icons
  - Improvements to the sizing of icons and other user interface
    elements on high-DPI displays. For technical reasons,
    existing theme settings have been reverted to their default
    values. They can be changed again in the settings dialog.
  - Make use of the Unix.ownername and Unix.groupname facts for
    MLSD if available
  * Bugfixes and minor changes:
  - The bookmarks menu updates again after changing global
    bookmarks
  - Adding a site to the Site Manager as part of adding a
    site-specific bookmark no longer fails if sitemanager.xml
    does not yet exist
  - Strip byte order marks at the beginning of directory listings
  - Add an option to filezilla.xml to control cache ttl
* Sun Nov 20 2016 ecsos@opensuse.org
- update to 3.22.2.2
  * Bugfixes and minor changes:
  - Fixed trimming of FEAT response lines leading to incorrectly
    detected server features
- update to 3.22.2.1
  * Bugfixes and minor changes:
  - OS X: Rebuilt to work around a nasty bug in XCode: Even when
    linking with -Wl,-no-weak-imports it links against functions
    not available on older OS X versions
  - Fixed a crash on exotic servers only implementing factless
    MLST/MLSD
- update to 3.22.2
  * Bugfixes and minor changes:
  - Tuned appearance of progress bar in transfer queue
- update to 3.22.2-rc2
  * Bugfixes and minor changes:
  - SFTP: Renaming a file or directory where the new name already
    refers to a directory no longer moves the file into this
    directory.
  - Fix regression from -rc1 with custom ports in the
    quickconnect bar
  - Fix regression from -rc1 parsing the EPSV reply
- update to 3.22.2-rc1
  * New features:
    + Building and running FileZilla now depends on
    libfilezilla >= 0.8.0 (https://lib.filezilla-project.org/).
  * Bugfixes and minor changes:
  - Non-existing key files are no longer silently dropped from
    the SFTP page in the settings dialog
  - Further abbreviate log output if transferring files using
    SFTP
  - Generic proxy usernames and passwords containing non-ASCII
    characters are again handled correctly
  - Fixed an assertion if Ctrl+A is pressed in an empty file list
  - *nix: Fixed color of status message in the message log
  - *nix, OS X: Fixed an assertion adding files to the queue
    after having selected a large range of items
  - *nix, OS X: Fixed an assertion due to a timing issue when
    renaming local files
- rebase buildinfo-no-date.patch
  - Drop Patch filezilla-3.5.3-buildinfo-no-date.patch
  - Add Patch filezilla-3.22.2-buildinfo-no-date.patch
* Sat Oct  8 2016 ecsos@opensuse.org
- update to 3.22.1
  * Bugfixes and minor changes:
  - OS X: Work around a nasty bug in XCode where programs
    explicitly compiled for older versions of OS X were silently
    pulling in features exclusive to the new version, resulting
    in crashes at runtime
  - Fixed a potential crash when using SFTP
* Sun Oct  2 2016 ecsos@opensuse.org
- update to 3.22.0
  * Bugfixes and minor changes:
  - Bookmarks with the "Directory comparison" checkbox set now
    work correctly
  - MSW: Fix background clearing issue on the size format
    settings page
  - MSW: Toggling the log timestamp option no longer results in
    wrong log colors
  - Fix for premature queue completion action
- update to 3.22.0-rc1
  * New features:
  - Directory listing filters can now be exported and imported
  - Added the "not all" filter match type to filter out all items
    not matching all conditions
  - Added the "not all" search match type to search for all items
    not matching all conditions
  - Building and running FileZilla now depends on libfilezilla
    >= 0.7.0 (https://lib.filezilla-project.org/).
  - Building and running FileZilla now depends on GnuTLS
    >= 3.4.15
  * Bugfixes and minor changes:
  - Speed up creation of socket and file i/o threads through the
    use of a thread pool
  - Replace invalid characters in filenames when calculating the
    local filename for editing remote files
  - The updater can now handle HTTPS servers that redirect to
    other HTTPS servers
  - SFTP: Try password based login if a password-protected
    keyfile is rejected by the server instead of failing the
    login
  - MSW: Tee shell extension now supports long paths on
    Windows 10
* Thu Aug 25 2016 ecsos@opensuse.org
- update to 3.21.0
  * Fixed vulnerabilities:
  - Fixed a string format vulnerability introduced in 3.20.0-rc1
    when listing directories using SFTP
  * New features:
  - SFTP: Added support for AES-GCM ciphers as implemented in
    OpenSSH
  - OS X: Ctrl+Tab and Ctrl+Shift+Tab can now be used to switch
    forward and backward between opened tabs
* Thu Aug  4 2016 ecsos@opensuse.org
- update to 3.20.1
  * Bugfixes and minor changes:
  - Fixed rename file exists action on downloads
  - Fixed possible crash if disabling log abbreviation
  - Official binaries now link against a patched version of
    GnuTLS so that a better error message can be printed on
    broken servers that send malformed certificate chains
- update to 3.20.0
  * New features:
  - Display error message if entering a non-existing path on
    local file search
  - Building and running FileZilla now depends on
    libfilezilla >= 0.6.1 (https://lib.filezilla-project.org/).
- update to 3.20.0-rc1
  * New features:
  - Building and running FileZilla now depends on
    libfilezilla >= 0.6.0 (https://lib.filezilla-project.org/).
  - Building and running FileZilla now depends on GnuTLS 3.4.0
    or higher
  * Bugfixes and minor changes:
  - Fixed regression introduced in 3.19.0-rc1, reconnecting again
    uses the last used remote directory instead of the initial
    default remote directory
  - Fixed crash if creating a new site via the bookmarks dialog
  - Queuing remote directories for transfer no longer exits
    comparison mode
  - Fixed a rare crash using FTP over TLS if the control
    connection fails at the same time the data connection gets
    established
  - Entering invalid regular expressions in filter and search
    conditions now shows an error message
  - Fixed title of search dialog
  - Stricter certificate chain validation to supplement the Tofu
    model
  - *nix: Fix initial size of Site Manager dialog with some GTK
    versions
* Tue Jun 28 2016 ecsos@opensuse.org
- update to 3.19.0
  * New features:
  - Building FileZilla now depends on libfilezilla >= 0.5.3
    (https://lib.filezilla-project.org/).
  * Bugfixes and minor changes:
  - Fixed context menu in search dialog if not connected to
    server
  - OS X, *nix: Fix displayed text in file list status bar if
    selecting a single item in the file list out of multiple
    already selected items
- update to 3.19.0-rc1
  * New features:
  - In the Site Manager a background colour for sites can now be
    selected
  - Open tabs can be re-arranged using drag&drop
  * Bugfixes and minor changes:
  - Fixed copying URLs of multiple selected files to clipboard
  - Setting remote file timestamps did not take timezone offsets
    configured through the Site Manager into account
* Sat May 28 2016 ecsos@opensuse.org
- update to 3.18.0
  * Bugfixes and minor changes:
  - Small fixes to local file search
  - Fixed a regression introduced in 3.18.0-rc1 when formatting
    hostnames for display
- update to 3.18.0-rc1
  * New features:
  - The search functionality can now also be used to search local
    file
  - Reduced CPU consumption of adding files to the list of search
    results
  - Opening the remote context menu while holding shift allows
    copying URLs to clipboard that include the password
  - Added an option to the configuration file through which
    initiating drag&drop can be disallowed
  - Reduced memory footprint of some data structures
  - Building FileZilla now depends on libfilezilla >= 0.5.2
    (https://lib.filezilla-project.org/).
  * Bugfixes and minor changes:
  - The remote file list context menu no longer shows
    inapplicable entries while files are being added to queue
  - Fix date validation in filter and search conditions
- Drop filezilla-wxstring.patch because no more compatible
* Tue May 10 2016 ecsos@opensuse.org
- update to 3.17.0.1
  - SFTP: Fixed resuming SFTP transfers
  - MSW: Loading the system default locale no longer fails on
    systems that have any English locale installed, yet do not have
    the US-English locale installed
  - Fixed crash if update dialog is opened at the very same moment
    FileZilla is being closed.
- Add Patch filezilla-wxstring.patch for wxString conversion bug.
* Wed Apr 27 2016 joerg.lorenzen@ki.tng.de
- update to 3.17.0
  - *nix: Removed a label on the filter dialog that doesn't apply
    to *nix builds.
  - Fix compilation if Nettle is installed in a custom location.
  - Fix potential issues with destruction order when closing
    FileZilla.
- update to 3.17.0-rc1
  + Recursivly queuing local files for upload now displays the
    progress below the local file list.
  + MSW: Use dynamic TCP send buffer sizes to improve upload
    speeds on high-latency connections.
  + SFTP: Use hardware-accelerated AES on x86_64 CPUs if available
    by using the AES implementation from Nettle instead of PuTTY.
  + Building FileZilla now depends on the Nettle library,
    version 3.1 or later.
  + Building FileZilla now depends on libfilezilla >= 0.5.0
    (https://lib.filezilla-project.org/).
  - MSW: The installer now warns if it detects old versions of
    FileZilla outside of the installation directory.
  - Improve compatibility with directory listings where midnight
    is represented as 24:00:00 of the prior day.
  - SFTP: Failed downloads due to write failures, e.g. due to a
    full disk, no longer show up as successful.
  - SFTP: Fix transfer failures if multiple transfers try to list
    the same directory.
  - SFTP: Updated PuTTY components.
  - FTP over TLS: Debug logs now contain additional information
    about the TLS handshake.
- Fixed putty-no_DATE_and_TIME_.patch.
* Thu Mar 17 2016 ecsos@opensuse.org
- update to 3.16.1
  - Updated PuTTY components
  - Updated translations
  - Official binaries now link against GnuTLS 3.4.10
  - Official binaries now link against SQLite 3.11.1
- update to 3.16.0
  + Make notification bubble on queue completion configurable
    though the queue's context menu
  + Selected queue completion action is now remembered,
    excluding the system shutdown/sleep actions.
  + Added new servertype to the Site Manager for servers using
    MS-DOS style paths with forward slashes as separators
  + Building FileZilla now depends on libfilezilla >= 0.4.0
    (https://lib.filezilla-project.org/).
  - Fixes for network configuration wizard leading to incorrect
    test result
  - Small fix for remembering queue completion actions
* Sun Feb 28 2016 ecsos@opensuse.org
- update to 3.15.0.2
  - Restore focused item if changing directory listing sort order
  - Fix restoring the column widths of the failed transfers tab in
    the queue when starting FileZilla
- update to 3.15.0.1
  - Fix for search dialog not displaying the results from the last
    visited directory of a search
- update to 3.15.0
  - no changes for *nix
- update to 3.15.0-rc1
  - Fix regression from 3.16.0-beta1 where extra data being
    appended to some downloaded files
  - Fix setting initial pane sizes when creating new tabs
  - Updated SFTP components from PuTTY
  - Official binaries now link against GnuTLS 3.4.8
  - Official binaries now link against SQLite 3.10.2
- update to 3.15.0-beta1
  - Building FileZilla now depends on libfilezilla 0.3.0
    (https://lib.filezilla-project.org/).
  - Added support for downloading and deleting multiple unrelated
    directories from the search dialog
  - *nix: Vastly speed up line-ending conversion when downloading
    files using the ASCII data type
  - Improved compatibility with broken servers omitting the
    mandatory 1yz reply to transfer commands
  - Fix handling of SFTP keyfiles with non-ASCII characters in
    their paths
  - Add missing directory comparison checkbox to new bookmark
    dialog
  - Updated built-in pugixml
- Drop filezilla-3.14.1_wxstring.patch: now in upstream
- Drop filezilla-3.14.1_xml.patch: now in upstream
- add BuildRequires libfilezilla
- add Requires libpugixml1 boo#966384
* Sat Jan 16 2016 ramaxlo@gmail.com
- Revert locale fixing script to the original version. The simplified
  script will cause
  pt_BR.po & pt_PT.po --> pt.po
  zh_CN.po & zh_TW.po --> zh.po
  one of them will be overwritten by the other, depending on which one
  is converted last.
* Sat Dec  5 2015 sor.alexei@meowr.ru
- In openSUSE Leap 42.1 set C++ ABI to the one wxWidgets uses
  (boo#958060).
* Thu Nov  5 2015 sor.alexei@meowr.ru
- Only use explicit gcc5 for openSUSE Leap 42.1 (and older).
- Some spec simplifications.
- Update icon cache.
- Remove duplicate CXXFLAGS adding.
* Thu Nov  5 2015 aloisio@gmx.com
- Fixed compiler requirements, again.
* Tue Oct 27 2015 aloisio@gmx.com
- Added requirement for pugixml 1.7
* Tue Oct 27 2015 tchvatal@suse.com
- Simply rely on gcc-c++ from system as we won't build on older distros
  anyway
* Fri Oct 23 2015 aloisio@gmx.com
- Update to version 3.14.1 (2015-10-16)
  * For third-party builds, add configure flag to allow using
    system ciphers for FTP over TLS. Display a warning if an
    insecure cipher is negotiated as result of using system ciphers.
  * Fixed loading of the directory comparison flag for bookmakrs
    in the Site Manager
  * Changing the interface layout and icon theme no longer results
    in an inconsistent UI state
  * Some SFTP servers send additional information on errors. This
    information is now shown in the message log
  * If the local file cannot be opened on SFTP transfers FileZilla
    no longer automatically retries
  * Updated SFTP components from PuTTY
  3.14.0 (2015-09-16)
  * When connecting using SFTP, show an error message instead of
    silently failing when encountering an insecure cipher
  3.14.0-rc2 (2015-09-09)
  * Removing selected queue items is now faster
  * Reduced memory usage of queue
  * When connecting to hostnames with multiple IPs, reset timeout
    if trying the next address
  3.14.0-rc1 (2015-09-04)
  * Add support for password-protected SSH private keys
  * SSH private keys not in PuTTY's native format no longer need
    to be converted if they aren't password-protected
  * When using synchronized browsing, changing to a directory
    that does not exist on both sides now asks whether the missing
    directory should be created
  * SSH1 support for SFTP has been disabled
  3.13.1 (2015-08-24)
  * Fix SFTP component crashing on some combinations of encryption
    and key exchange algorithm
  * Fixed Ctrl+Shift+I shortcut to toggle filters
  * OS X: Fixed Ctrl+, shortcut to open settings dialog
  * Optimizations to reduce memory footprint
  * Build system fixes
- Added filezilla-3.14.1_wxstring.patch and filezilla-3.14.1_xml.patch
  to address build problems
- Dropped tinyxml requirements
* Fri Sep  4 2015 tchvatal@suse.com
- Add pugixml as dependency
* Fri Sep  4 2015 tchvatal@suse.com
- Version bump to 3.13.1:
  * Fix SFTP component crashing on some combinations of encryption and key
  * exchange algorithm
  * Fixed Ctrl+Shift+I shortcut to toggle filters
  * OS X: Fixed Ctrl+, shortcut to open settings dialog
  * Optimizations to reduce memory footprint
  * Build system fixes
  * Display home directory instead of root directory if the last used directory
  * does not exist
  * Larger initial size of main window if there is no stored size
  * Slightly increased size of page selection box in settings dialog
- Refresh patch:
  * filezilla-3.5.3-buildinfo-no-date.patch
* Sun Jul 19 2015 ecsos@opensuse.org
- version bump to 3.12.0.2:
  * Fix regression on servers that have MLSD facts disabled by
    default
- changes from 3.12.0.1:
  * Fix detection of UTF-8 support
  * Fix location of file list status bar, it was shifted by one
    pixel
* Fri Jul 10 2015 alarrosa@suse.com
- BuildRequire wxWidgets-3_0-devel in openSUSE 13.1, 13.2 and others
  (suse_version >= 1310) instead of wxWidgets-devel
* Fri Jul 10 2015 tchvatal@suse.com
- Version bump to 3.12.0:
  * Various small fixes all around
- Upstreamed patch:
  * filezilla-string-conversion.patch
* Sun Jun  7 2015 tchvatal@suse.com
- Version bump to 3.11.0.2:
  * Fix crasher during some server-client scenarios
  * Work with non-epoch time received from server
- Added patch:
  * filezilla-string-conversion.patch
* Wed May 27 2015 tchvatal@suse.com
- Version bump to 3.11.0.1:
  * Quite few small fixes around
* Tue Mar 31 2015 tchvatal@suse.com
- Version bump to 3.10.3:
  * Various small fixes
  * Merged suse patches
- Removed patches:
  * wxstring-conversions-fix.patch
  * fix-missing-include-fz-bug-10280.patch
* Sun Mar 22 2015 devel.suse@gmail.com
- Filezilla now requires wxWidgets >= 3.0.2
* Thu Mar 12 2015 tchvatal@suse.com
- Add patch to build with our wxwidgets wxstring-conversions-fix.patch
* Thu Mar 12 2015 tchvatal@suse.com
- Add patch fix-missing-include-fz-bug-10280.patch to fix build
* Tue Mar  3 2015 tchvatal@suse.com
- Version bump to 3.10.2:
  * In the XML files, passwords are now base64 encoded
  * The subject area in the certificate verification can now be scrolled if the
    certificate contains many alternative names
  * Many performance improvements
  * Various bugfixes
* Fri Oct  3 2014 tchvatal@suse.com
- Version bump to 3.9.0.5:
  * use wxwidgets-3.0
  * various layout fixes
  * assertion fixes
  * new additional iconset
- Accidentaly fix bnc#898879 by updating
* Thu Aug 14 2014 dimstar@opensuse.org
- Update to version 3.8.1:
  + OS X: Partial support for retina displays.
  + Fixed several small memory leaks.
- Changes from version 3.8.0:
  + Popup dialogs no longer automatically open if other dialogs are
    already open. This prevents FileZilla from becoming
    unresponsive on OS X
  + Fix calculation of current transfer speed. In some situations
    the transfer speed tooltip over the activity indicators showed
    negative speeds.
  + Fix handling of focus item in local directory listings if
    connecting to a site with a default local directory.
* Mon Jan 13 2014 tchvatal@suse.com
- Fix dependencies for the Factory build again and remove few
  useless lines.
* Fri Aug  9 2013 tchvatal@suse.com
- Version bump to 3.7.3
  - Full changelog: https://filezilla-project.org/changelog.php
  - Noteworthy changes:
  * Apply a fix for a security vulnerability in PuTTY as used in FileZilla to handle SFTP. See CVE-2013-4852 for reference.
  * Merge further fixes from PuTTY to address CVE-2013-4206, CVE-2013-4207, CVE-2013-4208
* Mon May 13 2013 tchvatal@suse.com
- Version bump to 3.7.0.1
  - Fix issues with bundled gnutls
  - Update translations
* Fri May 10 2013 tchvatal@suse.com
- Update to version 3.7.0. Changes since 3.6.0.2:
  - Show total transfer speed as tooltip over the transfer indicators
  - List supported protocols in tooltip of host field in quickconnect bar
  - Use TLS instead of the deprecated term SSL
  - Reworded text when saving of passwords is disabled, do not refer to kiosk mode
  - Improved usability of Update page in settings dialog
  - Improve SFTP performance
  - When navigating to the parent directory, highlight the former child
  - When editing files, use high priority for the transfers
  - Add label to size conditions in filter conditions dialog indicating that the unit is bytes
  - Ignore drag&drop operations where source and target are identical and clarify the wording in some drop error cases
  - Trim whitespace from the entered port numbers
  - Slightly darker color of inactive tabs
  - Ignore .. item in the file list context menus if multiple items are selected
  - Display TLS version and key exchange algorithm in certificate and encryption details dialog for FTP over TLS connections.
  - Fix handling of remote paths containing double-quotes
  - Fix crash when opening local directories in Explorer if the name contained characters not representable in the locale's narrow-width character set.
  - Fix a memory leak in the host key verification dialog for SFTP
  - Fix drag-scrolling in file lists with very low height
  - Don't attempt writing XML files upon loading them
  - Improve handling of legacy DDE file associations
  - Fix handling of HTTPS in the auto updater in case a mirror redirects to HTTPS
* Tue Mar  5 2013 nico.kruber@gmail.com
- Update to version 3.6.0.2. Changes since 3.5.3:
  - 3.6.0.2 (2012-11-29)
  * Fix problems with stalling FTP over TLS uploads
  * MSW: Minor performance increase listing local files
  - 3.6.0.1 (2012-11-18)
  * Fix problems with TLS cipher selection, including a bugfix
    for GnuTLS
  * Fix a crash on shutdown
  * Add log message for servers not using UTF-8
  * Small performance and memory optimizations getting file
    types
  * Improve formatting of transfer speeds
  - 3.6.0 (2012-11-10)
  * Fix a crash introduced since 3.5.3
  * IPv6-only hosts should no longer cause a crash in the
    network configuration wizard
* Thu Apr  5 2012 andreas.stieger@gmx.de
- add filezilla-3.5.3-buildinfo-no-date.patch
  fixing W: file-contains-date-and-time
* Tue Jan 10 2012 cstender@suse.com
- Update to version 3.5.3. Changes since 3.5.2:
  + Ctrl+Shift+O can be used to toggle between modification time and filesize based directory comparison
  - It is now possible to use custom passwords if using "anonymous" as user name
  - After un-hiding toolbar, update toolbar button states
  - Fix TLS compatibility issues with TLS 1.2 servers
  - MSW: Unset hidden attribute on FileZilla's settings files
  - Building FileZilla from source now requires wxWidgets 2.8.12 or higher.
* Wed Dec 14 2011 fisiu@opensuse.org
- Update to 3.5.2. Changes since 3.5.1:
    3.5.2 (2011-11-08)
  - Updated translations
    3.5.2-rc1 (2011-11-01)
    + Added option to open site manager on startup to the settings dialog
  - The "Don't save passwords" option was not being saved
  - The queue was not saved correctly if having items from multiple servers
  - Queue items with the lowest priority setting are now being restored again
  - Drag & Drop did not work with all saved sites if saving of passwords had been disabled
* Wed Oct 26 2011 fisiu@opensuse.org
- Update to 3.5.1. Changes since 3.4.0:
    3.5.1 (2011-08-28)
  - Add support for another rate variant of MVS style directory listings
    3.5.1-rc1 (2011-08-21)
    + Add menu item to hide toolbar
  - Don't save server list in kiosk mode 2
  - Fix for predefined sites not appearing in all circumstances
  - Fix typo in build script in detection of SQLite3
  - Fix character set conversion in desktop notification code
  - Merged upstream PuTTY changes for compatibility with PuTTY 0.61
  - Updated built-in TinyXML
    3.5.0 (2011-05-22)
  - Don't create queue.xml anymore if it does not exist
  - Several fixes to build system and environment
    3.5.0-rc2 (2011-05-15)
    + Added experimental setting to strip file revision upon download from VMS servers. Set "Strip VMS revisions" to 1 in FileZilla.xml to enable
  - The string coalescer benchmark debug option no longer crashes if benchmarking an empty string coalescer
    3.5.0-rc1 (2011-05-08)
    + The transfer queue is now stored in an SQLite database.
  - Fixed crash during shutdown of FileZilla
  - Clearing the queue when it was not yet fully populated no longer causes a crash
  - If using ask login type for a site and no username is given, the initial focus is now on the user box in the login dialog
* Fri Apr 29 2011 pth@novell.com
- Update to 3.4.0. Changes since 3.3.4.1:
    3.3.5-rc1 (2010-11-07)
    + FTP over TLS certificate store is now host-specific
    + MSW: Large-DPI awareness
    + Improved SFTP transfer speeds
    + FTP over TLS should prefer ciphers with longer key sizes
    + Add context menu entry to re-queue all files on the successful and
    failed queue tabs
  - Resuming of uploads was not working correctly in all cases
  - Correct remaining time calculation in queue
  - Do not show welcome dialog in kiosk mode 2
  - Do not offer option to permanently accept certificate in kiosk mode 2
  - Fix sorting by size in filelists with directory sort behavior set to
    inline
  - Directly save settings after importing from file
    3.3.5.1 (2010-11-21)
  - Permanently trusting certificates had no effect until FileZilla was
    restarted
  - Fix downloading of symbolic links to files
    3.4.0-beta1 (2011-01-09)
    + Added option to force use of insecure plain FTP to Site Manager
    + Kiosk mode option can now also be read from FileZilla.xml, with
    fzdefaults.xml having priority if setting exists in both files
  - Fix memory leak in directory cache
  - Compatibility with obscure DOS servers using forward slashes as path
    delimiter
  - Improve text wrapping engine
    3.4.0-rc1 (2011-03-20)
    + Add checkbox to settings dialog to not save passwords
    + Add timestamp columns to successful and failed queue tabs showing
    when the transfers completed or failed
  - Fixed infinite loop in TinyXML when loading settings from corrupt
    XML documents
  - Parsing MDTM reply now takes seconds into account
  - Compatibility with MVS listing containing PO-E type entries
  - Fix Resizing issues with manual transfers dialog
* Tue Apr  5 2011 pth@suse.de
- Fix typo in putty-no_DATE_and_TIME_.patch.
* Wed Dec 29 2010 sbrabec@suse.cz
- Compile with wxWidgets-wxcontainer, it does not compile with STL
  variant.
- Fixed invalid translation locales (filezilla#6514).
- Fixed project URL.
* Fri Nov  5 2010 pth@suse.de
- Update to 3.3.4.1:
  * Set a minimum size for column widths in directory lists and
    transfer queue.
  * Fix build-time check for system TinyXML.
  * Update german translation.
- Fix Provides and Obsoletes.
- Don't use __DATE__ and __TIME__ in included Putty source
  in order to reduce package rebuilds.
* Wed Mar 31 2010 pth@novell.com
- Use %%lang_package macro.
* Fri Mar 26 2010 pth@novell.com
- Refresh german message catalog and disambiguate messages
  marked fuzzy.
- Split off message catalogs into a -lang subpackage.
* Tue Mar 23 2010 per@osbeck.com
- update to v3.3.2.1
  - Remember location of update download directory
  - Cancel file renaming on actions that change the file list, such as changing sort order or performing a refresh
  - Cancel file renaming if starting a drag&drop operation
  - Filter invalid characters if downloading through double-clicking files or if adding from the search dialog
  - Fix site-specific bookmarks menu
  - The menu did not reflect initial value of preserve timestamp option properly
  - MSW: Keep FileZilla subdirectory in startmenu when updating, preserves custom order
  - MSW: Add AppID support to installer
* Tue Mar 16 2010 per@osbeck.com
- update to v3.3.2
- *nix: Add support for forward and backward mouse buttons
- Speed limits can be re-enabled on SFTP connections
- Changed settings did not come into effect unless FileZilla was restarted
- Small performance improvements
- Spelling fixes
- Rebuilt due to timer problems
- Speed limits can be quickly set using the menu and a new indicator in the status bar
- Display number of bytes transferred and duration of transfer in log
- MSW: React to back button of mouse in file lists
- Updated blukis icon set
- Refactored large parts of the toolbar and menubar code
- A race condition in the socket code could lead to crashes
- Fix connecting to addresses longer than 15 characters if using SOCKS proxy
- Get add to queue in local directory tree context menu working again
- Do not open request dialogs if user is holding a mouse button
- Forward all Ctrl+Tab key events to tab bar
- Do not report SFTP exitcodes that do not originate from the server
* Tue Feb 16 2010 seife@opensuse.org
- update to v3.3.1, to fix the build problems with newer libgnutls
* Thu Nov 22 2007 pth@suse.de
- Package renamed from FileZilla to filezilla because only the tarball
  is named with mixed case.
- Provide a filezilla-rpmlintrc
- Update to 3.0.3. Changes since 3.0.0.beta6:
  - Install some default filters if filters.xml missing in user's settings
    directory
  - Additional fixes for SFTP servers with nonstandard filename encodings
  - Automatic server timezone detection. Custom offset in the Site Manager
    may need to be adjusted. FTP only.
  - Option to preserve file timestamps on downloads (all protocols)
  - Option to preserve file timestamps on uploads on FTP servers supporting
    the MFMT command
  - Add transfer type (ascii/binary/auto) selection to transfer menu
  - Shorten very long filenames on file exists dialog
  - Attempt at working around broken routers and firewalls disconnecting
    the control connection of the transfer session on transfers
  - Deleting directories containing lots of files should be faster now
  - Disallow settings/site import from files located in the settings storage
    directory
  - Fix nullpointer dereference on non-UTF8 enabled SFTP servers
  - Fix button height inconsistencies on dialogs with certain artwork
    (e.g. Ubuntu 7.10)
  - Fix issue with message log not working properly
  - Experimental support for z/VM servers
  - Fix typo in option handling code. Due to this, settings for date/time
    formatting have been reset.
  - Fix performance problem if FileZilla gets started with message log
    hidden
  - Work around possible race conditions in SFTP input thread leading to
    crashes
  - Remote file viewing / editing
  - Display current server in window title
  - Don't remember incorrect password on SFTP connections with ASK
    logontype
  - Fix Makefiles so SFTP properly supports files > 2GB
  - Ascii filetype setting for extensionless files and dotfiles had
    negated effect
  - Fix error message if using multiple running instances save the
    settings at the same time
  - Fix parsing of very new files in directory listings if server is in a
    timezone ahead of the client
  - Fix range of timezone offset setting
  - Fix problems with remote path combobox if reconnecting after a
    disconnect
  - Display confirmation dialog if deleting file from remote directory
    tree context menu
  - Refresh remote directory listing after refreshing a single file
  - On very first startup, center FileZilla on screen
  - Fix parsing of settings or site XML data containing double, leading or
    trailing whitespace.
  - Settings to configure size, date and time formatting
  - Message log and queue visibility will be remembered
  - Custom action to perform after queue completion
  - Add some confirmation dialogs
  - Fix misplaced settings dialog
  - Fix problems with remembering pane size
  - Properly refresh local directory if downloading into newly created
    subdirectories
  - Fix issues with language set to Japanese
  - New application icon
  - Fix support for servers sending directory listing in yet another
    exotic format
  - Fix prefix search in list controls on wxGTK
  - Work around problem with wxSpinCtrl in site manager on wxGTK
  - Fix assertion on wxGTK if listing extensionless files
  - Fix buffer overflow if directory lisiting filters were enabled,
    causing FileZilla to crash.
  - Backspace key can be used to goes to parent directory in file lists
  - Fix file selection by entering filename prefix
  - Restore correct window size if FileZilla gets closed while minimized
  - Disable "Create directory" entry in remote filelist context menu
    while disconnected
  - Improve compatibility with SFTP servers using exotic listing formats
  - Fix queue scrolling
  - Remember Window size and position
  - Remember sort column and order of file lists
  - Additional icon set by Brian Lukis
  - Added .desktop file on *nix systems
  - If server is crippled and doesn't allow more than one connection
    (based on Sitemanager preference), primary browsing connection can be
    used by the transfer queue
  - Fix SSL transfers hanging if using speed limits
  - Compile fixes and compatibility improvements for various platforms
  - The usual assortment of small bugfixes, see changelog for details
  - Fix remotely triggered memory corruption if connection gets terminated
    during TLS handshake.
  - Column withs in all list views will be saved
  - Refresh local file list after a successful file transfer
  - Add context menu to remote directory tree
  - Make Site Manager resizable
  - Don't leave empty files behind on failed downloads
  - Fix retry and cache logic if transfer command fails with 5yz reply
  - Limit number of simultaneous connections did not work properly
  - Refresh listing after chmod
  - Fix upload of empty files over TLS connections
  - Improved queue
  - Import and export dialogs including import of Sitemanager data
    from legacy FZ 2.x
  - Tab key can be used to switch between panes
  - F6 toggles between quickconnect bar and local/remote path edit fields
  - Location of settings directory can be specified in fzdefaults.xml
  - Engine state could get mixed up if transfers failed
  - Transfer of empty files could incorrectly time out
  - Fix directory cache coherency if removing/renaming directories
  - Work around lack of thread-safety in wxWidgets causing random
    misbehaviour
  - Properly disconnect idle transfer engines after 30 seconds
  - Update selections if changing sort order of file lists
  - Various minor fixes
  - Add "View hidden files" option to server menu
  - Add dialog to clear private data
  - Performance improvements of message log
  - Avoid sending unnecessary TYPE commands
  - Updated TinyXML component, fixes problems with filenames
    containing ampersands or other special XML entities.
  - Don't retry connecting if user cancels new/changed hostkey
    notification
  - Fix data corruption on FTPS uploads
  - Implement speed limits
  - Last used local directory will be remembered
  - New option for the sorting of the filelists. Directories can be kept
    on top or sorted inline.
  - Display warning if detecting a Windows system with a networking bug
    confirmed by Microsoft
  - Right-clicking the Sitemanager button in the toolbar displays a popup
    menu with the sites for quick access. On Windows, a dropdown arrow got
    added.
  - Autocompletion did not work properly on GTK based systems
  - Uninstalling FileZilla on Windows should no longer leave registry keys
    behind
  - lots of small bugfixes
  - New optionspage to change layout of file and directory panes
  - Loading of predefined Sitemanager entries from fzdefaults.xml
  - UTF-8 support for SFTP, merged in upstream changes from PuTTY.
  - Ascii file FTP transfers should now work properly on non-Windows
    systems
  - Fix SFTP transfers of filenames containing the following
    characters: [ ] \ * ?
  - lots of small bugfixes and performance improvements
* Wed May 16 2007 pth@suse.de
- Fix comparison of pointer with string.
* Fri May  4 2007 pth@suse.de
- Initial package
